{% for message in request.session.pop_flash() %}
    <div class="alert alert-small alert-{{ message['type'] }}" role="alert">
        <button type="button" class="close" data-dismiss="alert" aria-label="Close"><span
                aria-hidden="true">&times;</span></button>
        {% if message['source'] %}<b style="font-size: larger; letter-spacing: -1px">{{ _(message['source'], mapping=message['mapping']) | safe }}</b>:{% endif %}
        {{ _(message['body'], mapping=message['mapping']) | safe}}
    </div>
{% endfor %}